.. _all-salt.states:

==================================
Full list of builtin state modules
==================================

.. currentmodule:: salt.states

.. autosummary::
    :toctree:
    :template: autosummary.rst.tmpl

    alias
    alternatives
    cmd
    cron
    debconfmod
    file
    gem
    git
    grains
    group
    hg
    host
    keyboard
    kmod
    layman
    libvirt
    locale
    makeconf
    module
    mongodb_database
    mongodb_user
    mount
    mysql_database
    mysql_grants
    mysql_user
    network
    pecl
    pip
    pkgng
    pkg
    pkgrepo
    postgres_database
    postgres_user
    postgres_group
    rabbitmq_user
    rabbitmq_vhost
    rvm
    selinux
    service
    ssh_auth
    ssh_known_hosts
    stateconf
    supervisord
    svn
    sysctl
    timezone
    user
    virtualenv
